# 8-channel RF power amplifier assembly and testing

![8-channel RF power amplifier](./images/8-channel_braodbandRFPA_assembled.jpg "Photograph of the assembled 8-channel RFPA")

Figure 1 - Photograph of an assembled 8-channel RFPA

[[_TOC_]]

## General description
The parallel transmission (pTx) RF amplifier is used to separately control the amplitude and phase of eight transmission channels for pTx experiments. 

## System design
As a main component the broadband high power amplifier ZHL-20W-13SW+ (SN: RB81028153) was used to amplify the signals of the eight channels. The maximum input power for each channel is - 3 dBm (see also the data sheet [ZHL-20W-13SW+](./datasheets/Amplifier_Datasheet_ZHL-20W-13SW+.pdf)). A wiring diagram of the PTX amplifier is displayed in Figure 2. 

![8ch RFPA wiring diagram](./images/rfpa_wiring_diagram.png "Wiring diagram of 8-channel RFPA")

**Figure 2** - Wiring diagram of the 8-channel amplifier. The components used can be found in Table 1.


| Item No. | Component        | Function                             | Part name             | Est. cost per Pc. [€] | Amount | Total cost [€]            |
| -----    | --------         | ---------                            | ---------             | -----                 | -----  | -----                     |
| 1        | SMA connector    | RF input                             | [Huber & Suhner, 34SMA-50-0-1/111NE](https://ecatalog.hubersuhner.com/product/E-Catalog/Radio-frequency/Adapters/23009027/34-SMA-50-0-1-111-NE?gv_refer=catsearch "Open manufacturer website")           | 16                    | 8      | 128                       | 
| 2        | BNC connector    | Input external 5V TTL signal         | [Telegärtner,100023404](https://www.telegaertner.com/artikel/onlinekatalog-koax/bnc/bnc-einbaubuchse-loetanschluss/bnc-einbaubuchse-100023404 "Open manufacturer website")        | 6                     | 1      | 6                         | 
| 3        | Toggle switch    | TTL or manual blanking               | [Marquardt, 9047.0202 Kippschalter  ](https://www.conrad.de/de/p/marquardt-9047-0202-kippschalter-30-v-dc-4-a-2-x-ein-ein-rastend-1-st-703181.html?hk=SEM&WT.mc_id=google_pla&gclid=CjwKCAiA2fmdBhBpEiwA4CcHzRn1aeqaXUZ1M-aVNl-45gknkgcLPw4zCxrzS4WeZpgKRog_U_80ixoCIrkQAvD_BwE "Open distributer website")     | 23                    | 1      | 23                        | 
| 4        | On/off-switch    | 230 V power switch                   | [S Socken, RK-1-01](https://www.regoh.de/soken-kippschalter-schalter-rk1-01-mit-kontrolle "Open distributer website")     | 15                    | 1      | 15                        | 
| 5        | SMA connector    | Output RF signal                     | [Huber & Suhner, 34SMA-50-0-1/111NE](https://ecatalog.hubersuhner.com/product/E-Catalog/Radio-frequency/Adapters/23009027/34-SMA-50-0-1-111-NE?gv_refer=catsearch "Open manufacturer website")           | 16                    | 8     | 128                       | 
| 6        | Fuse             | 10 A / electrical protection         | [Eaton, GBB 10 A](https://www.eaton.com/content/dam/eaton/products/electronic-components/resources/data-sheet/eaton-gbb-ceramic-tube-fuses-data-sheet.pdf "Open manufacturer website")   | 12.9                  | 1      | 12.9                      | 
| 7        | C14 connector    | Main power supply connector          | [Bulgin, PF0030/28](https://www.bulgin.com/en/products/iec-connector-flange-mount-twin-fused-inlet-pf0030-series-2-8mm-solder-tag-termination-en60-320-1-standard-sheet-c14-class-i.html "Open manufacturer website")   | 6                     | 1      | 6                         | 
| 8        | 24V Power supply | RSP-1000-24                          | [Mean Well, RSP-100-24](https://www.meanwell-web.com/en-gb/ac-dc-single-output-enclosed-power-supply-output-rsp--100--24 "Open manufacturer website")      | 40                    | 1      | 40                        | 
| 9        | 5V  Power supply | Auxiliary voltage for blanking       | [Egston, N1hFSW3](https://www.conrad.de/de/p/egston-n1hfsw3-18-ac-dc-einbaunetzteil-2-5-a-18-w-5-v-dc-2357648.html "Open distributer website")   | 31                    | 1      | 31                        | 
| 10-17    | RFPA module      | 20W power amplifier module           | [Mini-Circuits, ZHL-20W-13SWX+](https://www.minicircuits.com/WebStore/dashboard.html?model=ZHL-20W-13SWX%2B "Open manufacturer website")          | 1485                  | 8      | 11880                     | 
| 18       | Coaxial cable    | 500 mm connector                     | [Farnell, Konfektioniert RG316     ]("Open manufacturer website")    | 26                    | 16     | 416                       | 
| 19       | Housing          |                                      | [Schroff, 6 He Fa. May             ]("Open manufacturer website")    | 300                   | 1      | 300                       | 

**Table 1** - Components used in RFPA build.


![RFPA front view](./images/8-channel_braodbandRFPA_front.jpg "Front view of RFPA with annotations")

**Figure 3** - Front view of RFPA with annotated components (see Table 1)

![RFPA rear view](./images/8-channel_braodbandRFPA_rear.jpg "Rear view of RFPA with annotations")

**Figure 4** - Rear view of RFPA with annotated components (see Table 1)

![RFPA top view](./images/8-channel_braodbandRFPA_topview.jpg "Top view of RFPA without cover and annotations")

**Figure 5** - Top view of the RFPA with the cover removed and annotated components (see Table 1)


## Functionality

Before switching on the PTX amplifier, the unit must be connected to the mains voltage (230 V / 50 Hz) at the C14 socket ⑦ and an input or output signal must be connected to the eight channels ① and ⑤Then the PTX amplifier can be switched on with the rocker switch ④. 
The rocker switch ③ can be used to select between internal manual unblanking (rocker switch right, ON) and blanking by an external TTL signal (rocker switch left, TTL). A 5 V TTL signal can be connected to the BNC socket ②. Unblanking is necessary to unlock the amplifier modules. 

## Functional tests

### Test of the supply current
By measuring the supply current I<sub>SC</sub>, the general function of the individual amplifiers (High Power Amplifier ZHL-20W-13SW+) is to be tested. For this purpose, a multimeter (VOLTCRAFT MT-51, SN: 09126841) was inserted into the current path of the supply current I<sub>SC</sub>. According to the amplifier's data sheet, the supply current I<sub>SC</sub> is max. 2.8 A during proper operation (with fan). The values measured (Table 2) are within the tolerances.



| Channel No. | V<sub>out</sub> for P<sub>in</sub>=-20 dBm *f=123 MHz* | V<sub>out</sub> for P<sub>in</sub>=-10 dBm *f=123 MHz* | V<sub>out</sub> for P<sub>in</sub>=-20 dBm *f=297 MHz* | V<sub>out</sub> for P<sub>in</sub>=-10 dBm *f=297 MHz* |
| -----       | --------                        | -----                       |  -----                         | ----                     |   
| 1           | 682 mV<sub>pp</sub>             | 2.000 V<sub>pp</sub>        | 550 mV<sub>pp</sub>            | 1.710 V<sub>pp</sub>     |  
| 2           | 680 mV<sub>pp</sub>             | 2.010 V<sub>pp</sub>        | 554 mV<sub>pp</sub>            | 1.700 V<sub>pp</sub>     |  
| 3           | 680 mV<sub>pp</sub>             | 2.010 V<sub>pp</sub>        | 554 mV<sub>pp</sub>            | 1.700 V<sub>pp</sub>     |  
| 4           | 694 mV<sub>pp</sub>             | 2.040 V<sub>pp</sub>        | 566 mV<sub>pp</sub>            | 1.740 V<sub>pp</sub>     |  
| 5           | 690 mV<sub>pp</sub>             | 2.020 V<sub>pp</sub>        | 556 mV<sub>pp</sub>            | 1.730 V<sub>pp</sub>     |  
| 6           | 718 mV<sub>pp</sub>             | 2.110 V<sub>pp</sub>        | 590 mV<sub>pp</sub>            | 1.840 V<sub>pp</sub>     |  
| 7           | 676 mV<sub>pp</sub>             | 2.000 V<sub>pp</sub>        | 546 mV<sub>pp</sub>            | 1.690 V<sub>pp</sub>     |  
| 8           | 696 mV<sub>pp</sub>             | 2.060 V<sub>pp</sub>        | 578 mV<sub>pp</sub>            | 1.790 V<sub>pp</sub>     |  

### Testing of electrical safety

The electrical safety test was carried out in accordance with DIN 0701 0702. 

### Power measurement

The power measurement is intended to test the general function of the PTX amplifier. For the test setup, an attenuator, an oscilloscope and a signal generator were used as displayed in Figure 6. The attenuator has an attenuation factor of -30 dB. The measured results are displayed in Table 3.

![Power Measurement Setup](./images/power_measurement_setup.jpg "Power Measurement Setup") 

**Figure 6** - Power Measurement setup is shown.



